==> xoonips-3.42.tar.gz: xoonips-3.42/itemtypes/xnpfiles/language/english/main.php <==
<?php
// $Revision: 1.1.8.1.2.3 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.8.1.2.3 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XNPFILES_EXPERIMENTER_LABEL", "Experimenter" );
define( "_MD_XNPFILES_DATA_TYPE_LABEL", "Data type" );
define( "_MD_XNPFILES_DATE_LABEL", "Date" );
define( "_MD_XNPFILES_YEAR_LABEL", "year" );
define( "_MD_XNPFILES_MONTH_LABEL", "month" );
define( "_MD_XNPFILES_DAY_OF_MONTH_LABEL", "day" );
define( "_MD_XNPFILES_DATA_FILE_LABEL", "File" );
define( "_MD_XNPFILES_DATA_FILE_NAME", "- File Name" );
define( "_MD_XNPFILES_DATA_FILE_MIMETYPE", "- MIMEtype" );
define( "_MD_XNPFILES_DATA_FILE_FILETYPE", "- File type" );
define( "_MD_XNPFILES_CAPTION_LABEL", "Caption" );
define( "_MD_XNPFILES_EXPERIMENTER_REQUIRED", "Please enter 'Experimenter'" );
define( "_MD_XNPFILES_DATA_FILE_REQUIRED", "Please enter 'Data File'" );
define( '_MD_XNPFILES_README_REQUIRED' , "Please enter 'Readme'" );
define( '_MD_XNPFILES_LICENSE_REQUIRED', "Please enter 'License'" );
define( '_MD_XNPFILES_RIGHTS_REQUIRED' , "Please enter 'Rights'" );
define( '_MD_XNPFILES_EXPLANATION' , "Various types of File." );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_ID'           , 'Item ID' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_NAME'     , 'File Name' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_MIMETYPE' , 'MIMEtype' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_FILETYPE' , 'File type' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_FILE'         , 'File' );

?>

==> xoonips-3.48.tar.gz: xoonips-3.48/itemtypes/xnpfiles/language/english/main.php <==
<?php
// $Revision: 1.1.8.1.2.5 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2013 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.8.1.2.5 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XNPFILES_DATE_LABEL", "Date" );
define( "_MD_XNPFILES_DATA_FILE_LABEL", "File" );
define( "_MD_XNPFILES_DATA_FILE_NAME", "- File Name" );
define( "_MD_XNPFILES_DATA_FILE_MIMETYPE", "- MIME Type" );
define( "_MD_XNPFILES_DATA_FILE_FILETYPE", "- File Type" );
define( "_MD_XNPFILES_DATA_FILE_REQUIRED", "Please enter 'Data File'" );
define( '_MD_XNPFILES_EXPLANATION' , "Various types of File." );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_ID'           , 'Item ID' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_NAME'     , 'File Name' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_MIMETYPE' , 'MIME Type' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_FILETYPE' , 'File Type' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_FILE'         , 'File' );
